@@ -21,9 +21,10 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
     Q_ENUMS(FontModificationMode)
 
     explicit QOwnNotesMarkdownTextEdit(QWidget *parent = nullptr);
+    ~QOwnNotesMarkdownTextEdit() override;
 
     void setStyles();
-    void openUrl(const QString &urlString) override;
+    void openUrl(const QString &urlString, bool openInNewTab) override;
     //    void setViewportMargins(int left, int top, int right, int bottom);
     void setPaperMargins(int width = -1);
     int modifyFontSize(FontModificationMode mode);
@@ -40,6 +41,21 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
      */
     void toggleCase();
 
+    /**
+     * Register this editor as the active one for AI autocomplete
+     */
+    void registerAsActiveEditor();
+
+    /**
+     * Unregister this editor from receiving AI autocomplete
+     */
+    void unregisterAsActiveEditor();
+
+    /**
+     * Get the currently active editor for AI autocomplete
+     */
+    static QOwnNotesMarkdownTextEdit *getActiveEditorForAutocomplete();
+
     /**
      * Inserts an empty code block
      */
@@ -86,6 +102,17 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
 
     void updateIgnoredClickUrlRegexps();
 
+   public slots:
+    /**
+     * Called when AI autocomplete is completed
+     */
+    void onAiAutocompleteCompleted(const QString &result);
+
+    /**
+     * Called when AI autocomplete request times out or errors
+     */
+    void onAiAutocompleteTimeout(const QString &errorString);
+
    protected:
     // we must not override _highlighter or Windows will create a
     // QOwnNotesMarkdownHighlighter and MarkdownHighlighter instance
@@ -94,10 +121,10 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
     void insertFromMimeData(const QMimeData *source) override;
     void resizeEvent(QResizeEvent *event) override;
     bool eventFilter(QObject *obj, QEvent *event) override;
+    void keyPressEvent(QKeyEvent *e) override;
+    void focusInEvent(QFocusEvent *e) override;
 
    private:
-    bool _isSpellCheckingDisabled = false;
-
     /// @param in is true if zoom-in, false otherwise
     void onZoom(bool in);
 
@@ -108,4 +135,33 @@ class QOwnNotesMarkdownTextEdit : public QMarkdownTextEdit {
     void overrideFontSizeStyle(int fontSize);
 
     QMenu *spellCheckContextMenu(QPoint pos);
+
+    /**
+     * Requests AI autocomplete for the current text
+     */
+    void requestAiAutocomplete();
+
+    /**
+     * Shows the AI autocomplete suggestion
+     */
+    void showAiAutocompleteSuggestion(const QString &suggestion);
+
+    /**
+     * Hides/clears the AI autocomplete suggestion
+     */
+    void clearAiAutocompleteSuggestion();
+
+    /**
+     * Accepts the current AI autocomplete suggestion
+     */
+    void acceptAiAutocompleteSuggestion();
+
+    bool _isSpellCheckingDisabled = false;
+    QString _aiAutocompleteSuggestion;
+    int _aiAutocompletePosition = -1;
+    QTimer *_aiAutocompleteTimer = nullptr;
+    bool _isInsertingAiSuggestion = false;
+
+    // Static pointer to the currently active editor for AI autocomplete
+    static QOwnNotesMarkdownTextEdit *_activeAutocompleteEditor;
 };
